/*
 * Copyright (c) Members of the EGEE Collaboration. 2004. 
 * See http://www.eu-egee.org/partners/ for details on the copyright
 * holders.  
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 *
 *     http://www.apache.org/licenses/LICENSE-2.0 
 *
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 */

/*
 * 
 * Authors: Antonino Stefano Borgia <stefano.borgia@pd.infn.it>
 *
 */
import org.glite.ce.monitorapij.sensor.SensorException;
import org.glite.ce.monitorapij.sensor.SensorListener;
import org.glite.ce.monitorapij.sensor.SensorOutputDataFormat;

import junit.framework.TestCase;


/**
 * @author borgia
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public class AbstractSensorTest extends TestCase {

    private TestSensor abstractSensor = null;
    /*
     * @see TestCase#setUp()
     */
    protected void setUp() throws Exception {
        abstractSensor = new TestSensor();
        abstractSensor.init();
    }

    /*
     * Class under test for void AbstractSensor()
     */
    public void testAbstractSensor() {
        assertNotNull(abstractSensor);
    }

    /*
     * Class under test for void AbstractSensor(String, String)
     */
    public void testAbstractSensorStringString() {
    }

    public void testGetFormat() {
        String format = null;
        SensorOutputDataFormat sensorOutputDataFormat = null;
        sensorOutputDataFormat = abstractSensor.getFormat(format);
        assertNull(sensorOutputDataFormat);
        format = "";
        sensorOutputDataFormat = abstractSensor.getFormat(format);
        assertNull(sensorOutputDataFormat);
        format = "Test Dialect";
        sensorOutputDataFormat = abstractSensor.getFormat(format);
        assertNotNull(sensorOutputDataFormat);
        assertEquals("Test Dialect", sensorOutputDataFormat.getName());
        
    }

    public void testGetFormats() {
        SensorOutputDataFormat[] formats = abstractSensor.getFormats();
        assertNotNull(formats);
        assertEquals(1,formats.length);
        assertEquals("Test Dialect", formats[0].getName());
    }

    public void testSetGetDefaultFormat() {
        String format = null;
        SensorOutputDataFormat sensorOutputDataFormat = null;
        abstractSensor.setDefaultFormat(sensorOutputDataFormat);
        TestFormat testFormat = new TestFormat("nothing");
        abstractSensor.setDefaultFormat(testFormat);
        sensorOutputDataFormat = abstractSensor.getDefaultFormat();
        assertNotNull(sensorOutputDataFormat);
        assertEquals("nothing",sensorOutputDataFormat.getName());
        
        
    }

    public void testAddFormat() {
        abstractSensor.addFormat(null);
    }

    public void testRemoveFormat() {
        abstractSensor.removeFormat(null);
        TestFormat testFormat = new TestFormat("nothing");
        assertEquals(1,abstractSensor.getFormats().length);
        abstractSensor.addFormat(testFormat);
        assertEquals(2,abstractSensor.getFormats().length);
        abstractSensor.setDefaultFormat(testFormat);
        abstractSensor.removeFormat(testFormat);
        assertEquals(1,abstractSensor.getFormats().length);
    }

    /*
     * Class under test for boolean isFormatSupported(SensorOutputDataFormat)
     */
    public void testIsFormatSupportedSensorOutputDataFormat() {
        SensorOutputDataFormat sodf = null;
        boolean isSupported = abstractSensor.isFormatSupported(sodf);
        assertFalse(isSupported);
        TestFormat testFormat = new TestFormat("Test Dialect");
        isSupported = abstractSensor.isFormatSupported(testFormat);
        assertTrue(isSupported);
    }

    /*
     * Class under test for boolean isFormatSupported(String)
     */
    public void testIsFormatSupportedString() {
        String format = null;
        boolean isSupported = abstractSensor.isFormatSupported(format);
        assertFalse(isSupported);
        
    }

    public void testGetSensorListeners() {
        SensorListener[] sensorListeners = abstractSensor.getSensorListeners();
        assertEquals(0,sensorListeners.length);
        TestListener testSensorListener = new TestListener();
        abstractSensor.addSensorListener(testSensorListener);
        sensorListeners = abstractSensor.getSensorListeners();
        assertEquals(1,sensorListeners.length);
        abstractSensor.removeSensorListener(testSensorListener);
        sensorListeners = abstractSensor.getSensorListeners();
        assertEquals(0,sensorListeners.length);
    }

    public void testAddSensorListener() {
        abstractSensor.addSensorListener(null);
    }

    public void testRemoveSensorListener() {
        abstractSensor.removeSensorListener(null);
    }

//    public void testFireSensorEvent() {
//        TestSensorListener testSensorListener = new TestSensorListener();
//        abstractSensor.addSensorListener(testSensorListener);
//        TestSensor testSensor = new TestSensor();
//        TestSensorEvent testSensorEvent = new TestSensorEvent(testSensor,System.currentTimeMillis( ), "Test Event" );
////        abstractSensor.
//    }

    public void testInit() {
        try {
            abstractSensor.init();
        } catch (SensorException e) {
            e.printStackTrace();
        }
    }

    public void testStartSuspendResumeDestroySensor() {
        abstractSensor.startSensor();
        abstractSensor.suspendSensor();
        abstractSensor.resumeSensor();
        abstractSensor.destroySensor();
    }

    public void testRun() {
        Thread thisThread =  new Thread(abstractSensor);
        thisThread.start();
//        abstractSensor.run();
//        abstractSensor.resumeSensor();
//        thisThread.interrupt();
    }

    public void testDoOnMonitorEvent() {
    }

}
