/*
 * Copyright (c) Members of the EGEE Collaboration. 2004. 
 * See http://www.eu-egee.org/partners/ for details on the copyright
 * holders.  
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 *
 *     http://www.apache.org/licenses/LICENSE-2.0 
 *
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 */

/*
 * 
 * Authors: Antonino Stefano Borgia <stefano.borgia@pd.infn.it>
 *
 */

import org.glite.ce.monitorapij.sensor.BooleanLock;

import junit.framework.TestCase;

public class BooleanLockTest extends TestCase {
   
   private BooleanLock booleanLock;
   private boolean success;

   public static void main( String[] args ) {
      junit.textui.TestRunner.run( BooleanLockTest.class );
   }


   /*
    * @see TestCase#setUp()
    */
   protected void setUp( ) throws Exception {
      success = false;
      booleanLock = new BooleanLock();
   }


   /*
    * Class under test for void BooleanLock()
    */
   public void testBooleanLock( ) {
     assertTrue("Not expected value of booleanLock",booleanLock.isFalse());
      
   }


   /*
    * Class under test for void BooleanLock(boolean)
    */
   public void testBooleanLockboolean( ) {
      booleanLock = new BooleanLock(true);
      assertTrue("Not expected value of booleanLock",booleanLock.isTrue());
   }


   public void testSetValue( ) {
      assertTrue("Not expected value of booleanLock",booleanLock.isFalse());
      booleanLock.setValue(true);
      assertTrue("Not expected value of booleanLock",booleanLock.isTrue());
      booleanLock.setValue(true);
      assertTrue("Not expected value of booleanLock",booleanLock.isTrue());
      
   }


   public void testWaitToSetTrue( ) {
      booleanLock.setValue(true);
      BooleanLockThread booleanLockThread = new BooleanLockThread(booleanLock,"set value",false);
      try {
         booleanLockThread.start();
         success = booleanLock.waitToSetTrue(10000L);
         
      } catch( InterruptedException e ) {
         e.printStackTrace();
      }
      assertTrue("insuccess in setting true after waiting 10 seconds",success);
      booleanLockThread.destroy();
      
      // this time waiting for the 1 second timeout
      booleanLock.setValue(true);
      try {
         success = booleanLock.waitToSetTrue(1000L);
      } catch( InterruptedException e1 ) {
         e1.printStackTrace();
      }
      assertFalse("insuccess in setting true after waiting 1 second",success);

   }


   public void testWaitToSetFalse( ) {
      booleanLock.setValue(false);
      BooleanLockThread booleanLockThread = new BooleanLockThread(booleanLock,"set value",true);
      try {
         booleanLockThread.start();
         success = booleanLock.waitToSetFalse(0L);
      } catch( InterruptedException e ) {
         e.printStackTrace();
      }
      assertTrue("insuccess in setting false after waiting 2 second",success);
      booleanLockThread.destroy();
      
//    this time waiting for the 1 second timeout
      booleanLock.setValue(false);
      try {
         success = booleanLock.waitToSetFalse(1000L);
      } catch( InterruptedException e1 ) {
         e1.printStackTrace();
      }
      assertFalse("insuccess in setting false after waiting 1 second",success);
   }


   public void testIsTrue( ) {
      assertFalse("Not expected true value of booleanLock",booleanLock.isTrue());
   }


   public void testIsFalse( ) {
      assertTrue("Not expected false value of booleanLock",booleanLock.isFalse());
   }


   public void testWaitUntilTrue( ) {
      booleanLock.setValue(false);
      BooleanLockThread booleanLockThread = new BooleanLockThread(booleanLock,"set value",true);
      try {
         booleanLockThread.start();
         success = booleanLock.waitUntilTrue(10000L);
      } catch( InterruptedException e ) {
         e.printStackTrace();
      }
      assertTrue("insuccess in getting true value after waiting 10 second",success);
      booleanLockThread.destroy();
      
   }


   public void testWaitUntilFalse( ) {
      booleanLock.setValue(true);
      BooleanLockThread booleanLockThread = new BooleanLockThread(booleanLock,"set value",false);
      try {
         booleanLockThread.start();
         success = booleanLock.waitUntilFalse(10000L);
      } catch( InterruptedException e ) {
         e.printStackTrace();
      }
      assertTrue("insuccess in setting false after waiting 10 second",success);
      booleanLockThread.destroy();
   }



}
