/*
 * Copyright (c) Members of the EGEE Collaboration. 2004. 
 * See http://www.eu-egee.org/partners/ for details on the copyright
 * holders.  
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 *
 *     http://www.apache.org/licenses/LICENSE-2.0 
 *
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 */

/*
 * 
 * Authors: Antonino Stefano Borgia <stefano.borgia@pd.infn.it>
 *
 */


import org.apache.axis.MessageContext;
import org.apache.axis.types.URI.MalformedURIException;

import java.io.File;
import java.net.URI;
import org.glite.ce.monitorapij.resource.Resource;
import org.glite.ce.monitorapij.resource.ResourceListener;

import junit.framework.TestCase;

/**
 * @author borgia
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public class ResourceHolderTest extends TestCase {

    private TestHolder testHolder = null;
    private MessageContext messageContext = null;
    private String path ="";
    private URI resourcePath = null;
    private URI resourceConfigPath = null;
    private TestSensor testSensor = null;
    /*
     * @see TestCase#setUp()
     */
    protected void setUp() throws Exception {

        testSensor = new TestSensor();
       	TestUtilities testUtilities = new TestUtilities();
       	messageContext= testUtilities.getMessageContext();
       	path = (String)messageContext.getProperty( "sensorURI" );
       	resourcePath = new URI( path );
       	path = (String)messageContext.getProperty( "sensorConfigURI" );
       	resourceConfigPath = new URI( path );
       	testHolder = new TestHolder( messageContext, resourcePath, resourceConfigPath);
    }

    public void testRun() {
        testHolder.run();
    }

    /*
     * Class under test for void ResourceHolder(MessageContext, URI)
     */
    public void testResourceHolderMessageContextURI() {
        testHolder = new TestHolder(messageContext,resourcePath);
        assertNotNull(testHolder);
        
    }

    /*
     * Class under test for void ResourceHolder(MessageContext, URI, URI)
     */
    public void testResourceHolderMessageContextURIURI() {
        assertNotNull(testHolder);
    }

    public void testGetResourceURI() {
        URI uri = testHolder.getResourceURI();
        assertEquals(resourcePath,uri);
    }

    public void testGetConfigFileURI() {
        URI uri = testHolder.getConfigFileURI();
        assertEquals(resourceConfigPath,uri);
    }

    public void testAddResource() {
        TestSensor testSensor = new TestSensor();
        testSensor.setId(10);
        
        testHolder.addResource(testSensor);
        assertEquals(testSensor,testHolder.getResource(10));
        Resource[] resources = testHolder.getResources();
        assertEquals(1,resources.length);
        testHolder.removeResource(testSensor);
        resources = testHolder.getResources();
        assertEquals(0,resources.length);
    }


    public void testGetResource() {
        TestSensor testSensor = new TestSensor();
        testSensor.setId(10);
        testHolder.addResource(testSensor);
        testHolder.getResource(100);
    }


    public void testGetResourceByType() {
        TestSensor testSensor = new TestSensor();
        testSensor.setId(10);
        testSensor.setType("test");
        testHolder.addResource(testSensor);
        Resource[] resources = testHolder.getResourceByType("test");
        assertEquals("test",resources[0].getType());
        resources = testHolder.getResourceByType("nothing");
        assertEquals(0,resources.length);
    }

    public void testGetResourceByJARPath() {
        testSensor.setId(10);
        testSensor.setType("test");
        org.apache.axis.types.URI uri = null;
        try {
            uri = new org.apache.axis.types.URI(path);
        } catch (MalformedURIException e) {
            e.printStackTrace();
        }
        testSensor.setJarPath(uri);
        testHolder.addResource(testSensor);
        Resource[] resources = testHolder.getResourceByJARPath(uri);
        assertEquals("test",resources[0].getType());
    }

    public void testGetResourceByName() {
        testSensor.setName("testSensor");
        testSensor.setId(10);
        testHolder.addResource(testSensor);
        Resource[] resources = testHolder.getResourceByName("testSensor");
        assertEquals("testSensor",resources[0].getName());
        resources = testHolder.getResourceByName("nothing");
        assertEquals(0,resources.length);
    }

    public void testSetResources() {
        testHolder.setResources(null);
        Resource[] resources = new Resource[1];
        testSensor.setName("testSensor");
        testSensor.setId(10);
        resources[0] = testSensor;
        testHolder.setResources(resources);
        resources = testHolder.getResources();
        assertEquals("testSensor",resources[0].getName());
        testHolder.clear();
        resources = testHolder.getResources();
        assertEquals(0,resources.length);
       
    }
    


    public void testCheckNewResources() {
        assertTrue(testHolder.checkNewResources());
    }

    public void testGetResourceFileList() {
        File[] files = null;
        try {
            files = testHolder.getResourceFileList();
        } catch (Exception e) {
            e.printStackTrace();
        }
        assertEquals(1,files.length);

        Resource resource = null;
        try {
           resource =  testHolder.makeResourceInstance(files[0]);
            // testSensor.jar
        } catch (Exception e1) {
            // TODO Auto-generated catch block
            e1.printStackTrace();
        }
        assertEquals("TestSensor",resource.getName());
    }

    public void testMakeResourceInstance() {
    }

    public void testMakeResourceClass() {
        Exception exception = null;
        try {
            testHolder.makeResourceInstance(null);
        } catch (Exception e) {
            exception = e;
        }
        assertEquals("The jar file is null!",exception.getMessage());
    }


    public void testAddGetRemoveResourceListener() {
        ResourceListener[] listeners = testHolder.getSensorListeners();
        assertEquals(0,listeners.length);
        TestListener testListener = new TestListener();
        testHolder.addResourceListener(testListener);
        listeners = testHolder.getSensorListeners();
        assertEquals(1,listeners.length);
        testHolder.removeResourceListener(testListener);
        listeners = testHolder.getSensorListeners();
        assertEquals(0,listeners.length);
        
    }


    public void testFireResourceEvent() {
    }

}
