/*
 * Copyright (c) Members of the EGEE Collaboration. 2004. 
 * See http://www.eu-egee.org/partners/ for details on the copyright
 * holders.  
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 *
 *     http://www.apache.org/licenses/LICENSE-2.0 
 *
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 */

/*
 * 
 * Authors: Antonino Stefano Borgia <stefano.borgia@pd.infn.it>
 *
 */
import java.util.Calendar;

import org.glite.ce.monitorapij.sensor.Sensor;
import org.glite.ce.monitorapij.sensor.SensorEvent;
import org.glite.ce.monitorapij.sensor.SensorException;
import org.glite.ce.monitorapij.sensor.SensorOutputDataFormat;
import org.glite.ce.monitorapij.types.Query;

import java.util.Hashtable;

import junit.framework.TestCase;

/**
 * @author borgia
 *
 * TODO To change the template for this generated type comment go to
 * Window - Preferences - Java - Code Style - Code Templates
 */
public class SensorEventTest extends TestCase {

    
    private TestSensor testSensor;
    private SensorEvent sensorEvent;
    private Calendar calendar;
    private TestFormat testFormat = null;
    private SensorOutputDataFormat sensorOutputDataFormat = null; 
    /*
     * @see TestCase#setUp()
     */
    protected void setUp( ) throws Exception {
        testSensor = new TestSensor();
        testSensor.init();
        sensorEvent = new SensorEvent( testSensor , 1 );
     }

    /*
     * Class under test for Object clone()
     */
    public void testClone() {
        SensorEvent se = (SensorEvent) sensorEvent.clone();
        assertNotNull(se);
    }

    /*
     * Class under test for void SensorEvent(Sensor, int)
     */
    public void testSensorEventSensorint( ) {
        assertNotNull(sensorEvent);
     }

    /*
     * Class under test for void SensorEvent(Sensor, int, Calendar)
     */
    public void testSensorEventSensorintCalendar( ) {
        calendar = Calendar.getInstance( );
        // case sensor null
        testSensor=null;
        calendar = Calendar.getInstance( );
        sensorEvent = new SensorEvent(testSensor,1,calendar);
        assertNotNull(sensorEvent);
        
        // no exceptions
        testSensor = new TestSensor();
        sensorEvent = new SensorEvent(testSensor,1,calendar);
        assertNotNull(sensorEvent);
     }


    

    public void testGetAddParameter() {
        String parameter = (String)sensorEvent.getParameter("test");
        assertNull(parameter);
        sensorEvent.addParameter("test","success");
        parameter = (String)sensorEvent.getParameter("test");
        assertNotNull(parameter);
        assertEquals("success",parameter);
    }


    public void testGetSetParameters() {
        Hashtable parameters =  sensorEvent.getParameters();
        assertEquals(0,parameters.size());
        Hashtable newParameters =  new Hashtable();
        newParameters.put("another test","success");
        sensorEvent.setParameters(newParameters);
        parameters =  sensorEvent.getParameters();
        assertEquals(1,parameters.size());
        assertEquals("success",parameters.get("another test"));
        
    }


    /*
     * Class under test for void applyFormat(String)
     */
    public void testApplyFormatString() {
        sensorOutputDataFormat = sensorEvent.getSensorOutputDataFormatApplied();
        assertNull(sensorOutputDataFormat);
        String format = null;
        
        Exception exception = null;

        try {
            sensorEvent.applyFormat(format);
        } catch (SensorException e) {
            e.printStackTrace();
        }

        sensorOutputDataFormat = sensorEvent.getSensorOutputDataFormatApplied();
        assertNotNull(sensorOutputDataFormat);
        assertEquals("Test Dialect", sensorOutputDataFormat.getName());
        

        format = "Test Dialect";
        try {
            sensorEvent.applyFormat(format);
        } catch (SensorException e) {
            e.printStackTrace();
        }

        sensorOutputDataFormat = sensorEvent.getSensorOutputDataFormatApplied();
        assertNotNull(sensorOutputDataFormat);
        assertEquals("Test Dialect", sensorOutputDataFormat.getName());
    }

    /*
     * Class under test for void applyFormat(SensorOutputDataFormat)
     */
    public void testApplyGetFormatSensorOutputDataFormat() {

        sensorOutputDataFormat = sensorEvent.getSensorOutputDataFormatApplied();
        assertNull(sensorOutputDataFormat);
        
        Exception exception = null;
        try {
            sensorEvent.applyFormat(testFormat);
        } catch (SensorException e) {
            exception=e;
        }
        assertEquals("SensorEvent applyFormat: the sensor output dataformat is null!",exception.getMessage());
        
        
        testFormat = new TestFormat("test format");
        try {
            sensorEvent.applyFormat((SensorOutputDataFormat)testFormat);
        } catch (SensorException e) {
            exception=e;
        }
        assertEquals("SensorEvent applyFormat: \"test format\" format not supported!",exception.getMessage());
        
        testFormat = new TestFormat("Test Dialect");
        try {
            sensorEvent.applyFormat((SensorOutputDataFormat)testFormat);
        } catch (SensorException e) {
            e.printStackTrace();
        }
        sensorOutputDataFormat = sensorEvent.getSensorOutputDataFormatApplied();
        assertNotNull(sensorOutputDataFormat);
        assertEquals("Test Dialect", sensorOutputDataFormat.getName());
    }
//
//    public void testEvaluate() {
//        Exception exception = null;
//        try {
//            sensorEvent.evaluate(null);
//        } catch (SensorException e) {
//            exception = e;
//        }
//        assertEquals("SensorEvent evaluate: first apply a dataFormat!", exception.getMessage());
//        
//        try {
//            sensorEvent.applyFormat("Test Dialect");
//            sensorEvent.evaluate(null);
//        } catch (SensorException e1) {
//            exception = e1;
//        }
//        assertEquals("SensorEvent evaluate: the query is null!", exception.getMessage());
//        
//        Query query = new Query();
//        try {
//            sensorEvent.evaluate(query);
//        } catch (SensorException e1) {
//            exception = e1;
//        }
//        assertEquals("SensorEvent evaluate: the query expression is null!", exception.getMessage());
//        
//        query.setExpression("test");
//        try {
//            sensorEvent.evaluate(query);
//        } catch (SensorException e1) {
//            exception = e1;
//        }
//        assertEquals("SensorEvent evaluate: the query language is not supported", exception.getMessage());
//
//        query.setQueryLanguage("Test Dialect");
//        try {
//            sensorEvent.evaluate(query);
//        } catch (SensorException e1) {
//            exception = e1;
//        }
//        assertEquals("SensorEvent evaluate: the query language is not supported", exception.getMessage());
//
//        
//        
//   }

    public void testGetSource( ) {
        Sensor sensor = null;
        sensor = sensorEvent.getSource();
        assertNotNull(sensor);
     }

}
